@@ -11,7 +11,7 @@
     <message>
         <location filename="../selectwnd.ui" line="46"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation type="unfinished"></translation>
+        <translation>Välj tema för muspekaren (håll muspekaren över för förhandsvisning). &lt;b&gt; LXQt sessionen måste startas om efter den här ändringen&lt;/b&gt;:</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="23"/>
@@ -21,7 +21,7 @@
     <message>
         <location filename="../selectwnd.ui" line="72"/>
         <source>LXQt session needs restart to view this change.</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt-sessionen måste startas om för att visa den här ändringen.</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="91"/>
@@ -34,12 +34,12 @@
         <translation>Storlek</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="233"/>
+        <location filename="../selectwnd.cpp" line="231"/>
         <source>XCurTheme error</source>
-        <translation type="unfinished"></translation>
+        <translation>XCurTheme-fel</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="234"/>
+        <location filename="../selectwnd.cpp" line="232"/>
         <source>You can&apos;t remove active theme!</source>
         <translation>Du kan inte ta bort aktivt tema!</translation>
     </message>
@@ -49,12 +49,12 @@
     <message>
         <location filename="../warninglabel.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>Formulär</translation>
     </message>
     <message>
         <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt kunde inte hitta något markörtema. Standard X11-markörtema används istället. LXQt tittade i följande kataloger:</translation>
     </message>
     <message>
         <location filename="../warninglabel.ui" line="54"/>
