@@ -17,15 +17,25 @@
 <context>
     <name>ConfigOtherToolKits</name>
     <message>
-        <location filename="../configothertoolkits.cpp" line="148"/>
+        <location filename="../configothertoolkits.cpp" line="170"/>
         <source>GTK themes</source>
         <translation>Θέματα GTK</translation>
     </message>
     <message>
-        <location filename="../configothertoolkits.cpp" line="149"/>
+        <location filename="../configothertoolkits.cpp" line="171"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
         <translation>&lt;p&gt;Το %1 αντικαταστάθηκε.&lt;/p&gt;&lt;p&gt;Μπορείτε να βρείτε ένα αντίγραφο της παλιάς διαμόρφωσης στο &apos;%2&apos;&lt;/p&gt;</translation>
     </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error</source>
+        <translation>Σφάλμα</translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error: gsettings cannot be run</source>
+        <translation>Σφάλμα: αδυναμία εκτέλεσης του gsettings</translation>
+    </message>
 </context>
 <context>
     <name>FontsConfig</name>
@@ -151,6 +161,38 @@
         <translation>VBGR</translation>
     </message>
 </context>
+<context>
+    <name>GTKConfig</name>
+    <message>
+        <location filename="../gtkconfig.ui" line="44"/>
+        <source>GTK Style</source>
+        <translation>Τεχνοτροπία GTK</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="63"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
+        <translation>Ορισμός θεμάτων GTK (τα αρχεία διαμόρφωσης του GTK θα αντικατασταθούν!)</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="83"/>
+        <source>GTK 3 Theme</source>
+        <translation>Θέμα GTK 3</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="93"/>
+        <source>GTK 2 Theme</source>
+        <translation>Θέμα GTK 2</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="103"/>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation>Για να καταφέρετε μια ομοιόμορφη θεματοποίηση, μπορείτε είτε να επιλέξετε ένα παρεμφερές θέμα/τεχνοτροπία (αν είναι διαθέσιμο) από τα κατάστιχα, είτε να επιλέξετε την τεχνοτροπία Qt &apos;gtk&apos; (αν είναι διαθέσιμη) για την μίμηση των θεμάτων GTK.
+
+Σιγουρευτείτε ότι το &apos;xsettingsd&apos; είναι εγκατεστημένο ούτως ώστε να βοηθήσετε τις εφαρμογές GTK να εφαρμόζουν τα θέματα σε πραγματικό χρόνο.</translation>
+    </message>
+</context>
 <context>
     <name>IconThemeConfig</name>
     <message>
@@ -187,38 +229,62 @@
         <translation>Αντικατάσταση της καθορισμένης από τον χρήστη ταπετσαρίας</translation>
     </message>
 </context>
+<context>
+    <name>PalettesDialog</name>
+    <message>
+        <location filename="../palettes.ui" line="14"/>
+        <location filename="../palettes.ui" line="20"/>
+        <source>Palettes</source>
+        <translation>Χρωματοπυξίδες</translation>
+    </message>
+    <message>
+        <location filename="../palettes.ui" line="33"/>
+        <source>Filter...</source>
+        <translation>Φιλτράρισμα...</translation>
+    </message>
+    <message>
+        <location filename="../palettes.ui" line="43"/>
+        <source>&amp;Remove</source>
+        <translation>Α&amp;φαίρεση</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../main.cpp" line="62"/>
         <source>LXQt Appearance Configuration</source>
         <translation>Διαμόρφωση της εμφάνισης του LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="71"/>
+        <location filename="../main.cpp" line="75"/>
         <source>Widget Style</source>
         <translation>Τεχνοτροπία συστατικού</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="79"/>
+        <location filename="../main.cpp" line="84"/>
         <source>Icons Theme</source>
         <translation>Θέμα εικονιδίων</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="88"/>
+        <location filename="../main.cpp" line="93"/>
         <source>LXQt Theme</source>
         <translation>Θέμα LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../main.cpp" line="101"/>
         <source>Font</source>
         <translation>Γραμματοσειρά</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="106"/>
+        <location filename="../main.cpp" line="111"/>
         <source>Cursor</source>
         <translation>Δρομέας</translation>
     </message>
+    <message>
+        <location filename="../main.cpp" line="118"/>
+        <source>GTK Style</source>
+        <translation>Τεχνοτροπία GTK</translation>
+    </message>
 </context>
 <context>
     <name>StyleConfig</name>
@@ -278,66 +344,52 @@
         <translation>Επισκεφθέν δεσμός:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="227"/>
+        <location filename="../styleconfig.ui" line="214"/>
+        <source>&amp;Save Palette</source>
+        <translation>Α&amp;ποθήκευση χρωματοπυξίδας</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="221"/>
+        <source>&amp;Load Palette</source>
+        <translation>&amp;Φόρτωση χρωματοπυξίδας</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="241"/>
         <source>&amp;Default Palette</source>
         <translation>&amp;Προκαθορισμένη χρωματοπυξίδα</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="254"/>
-        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
-        <translation>Ορισμός θεμάτων GTK (τα αρχεία διαμόρφωσης του GTK θα αντικατασταθούν!)</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="274"/>
-        <source>GTK 3 Theme</source>
-        <translation>Θέμα GTK 3</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="284"/>
-        <source>GTK 2 Theme</source>
-        <translation>Θέμα GTK 2</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="294"/>
-        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
-
-Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation>Για να καταφέρετε μια ομοιόμορφη θεματοποίηση, μπορείτε είτε να επιλέξετε ένα παρεμφερές θέμα/τεχνοτροπία (αν είναι διαθέσιμο) από τα κατάστιχα, είτε να επιλέξετε την τεχνοτροπία Qt &apos;gtk&apos; (αν είναι διαθέσιμη) για την μίμηση των θεμάτων GTK.
-
-Σιγουρευτείτε ότι το &apos;xsettingsd&apos; είναι εγκατεστημένο ούτως ώστε να βοηθήσετε τις εφαρμογές GTK να εφαρμόζουν τα θέματα σε πραγματικό χρόνο.</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="311"/>
+        <location filename="../styleconfig.ui" line="256"/>
         <source>Toolbar button style:</source>
         <translation>Τεχνοτροπία των κουμπιών της γραμμής εργαλείων:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="319"/>
+        <location filename="../styleconfig.ui" line="264"/>
         <source>Only display the icon</source>
         <translation>Εμφάνιση μόνον του εικονιδίου</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="324"/>
+        <location filename="../styleconfig.ui" line="269"/>
         <source>Only display the text</source>
         <translation>Εμφάνιση μόνον του κειμένου</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="329"/>
+        <location filename="../styleconfig.ui" line="274"/>
         <source>The text appears beside the icon</source>
         <translation>Το κείμενο εμφανίζεται δίπλα από το εικονίδιο</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="334"/>
+        <location filename="../styleconfig.ui" line="279"/>
         <source>The text appears under the icon</source>
         <translation>Το κείμενο εμφανίζεται κάτω από το εικονίδιο</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="339"/>
+        <location filename="../styleconfig.ui" line="284"/>
         <source>Default</source>
         <translation>Εξ ορισμού</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="347"/>
+        <location filename="../styleconfig.ui" line="292"/>
         <source>Activate item on single click</source>
         <translation>Ενεργοποίηση των αντικειμένων με μονό κλικ</translation>
     </message>
@@ -346,5 +398,35 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
         <source>Qt Style</source>
         <translation>Τεχνοτροπία Qt</translation>
     </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <location filename="../styleconfig.cpp" line="255"/>
+        <source>Save Palette</source>
+        <translation>Αποθήκευση χρωματοπυξίδας</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <source>Palette name:</source>
+        <translation>Όνομα χρωματοπυξίδας:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="256"/>
+        <source>A palette with the same name exists.
+Do you want to replace it?</source>
+        <translation>Υπάρχει ήδη μια χρωματοπυξίδα με αυτό το όνομα.
+Θέλετε να την αντικαταστήσετε;</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="393"/>
+        <source>Remove Palettes</source>
+        <translation>Αφαίρεση χρωματοπυξίδων</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="394"/>
+        <source>Do you really want to remove selected palette(s)?
+Root palettes will remain intact if existing.</source>
+        <translation>Επιθυμείτε σίγουρα την αφαίρεση των επιλεγμένων χρωματοπυξίδων;
+Οι χρωματοπιξύδες Διαχειριστή —αν υπάρχουν— δεν θα επηρεαστούν.</translation>
+    </message>
 </context>
 </TS>
