@@ -17,15 +17,25 @@
 <context>
     <name>ConfigOtherToolKits</name>
     <message>
-        <location filename="../configothertoolkits.cpp" line="148"/>
+        <location filename="../configothertoolkits.cpp" line="170"/>
         <source>GTK themes</source>
         <translation>Temi GTK</translation>
     </message>
     <message>
-        <location filename="../configothertoolkits.cpp" line="149"/>
+        <location filename="../configothertoolkits.cpp" line="171"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
         <translation>&lt;p&gt;&apos;%1&apos; è stato sovrascritto.&lt;/p&gt;&lt;p&gt;E&apos; presente una copia delle vecchie impostazioni in &apos;%2&apos;&lt;/p&gt;</translation>
     </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error</source>
+        <translation>Errore</translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error: gsettings cannot be run</source>
+        <translation>Errore: non è possibile eseguire gsettings</translation>
+    </message>
 </context>
 <context>
     <name>FontsConfig</name>
@@ -152,6 +162,38 @@
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>GTKConfig</name>
+    <message>
+        <location filename="../gtkconfig.ui" line="44"/>
+        <source>GTK Style</source>
+        <translation>Stile GTK</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="63"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
+        <translation>Imposta tema GTK (verranno sovrascritti i file di configurazione di GTK!)</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="83"/>
+        <source>GTK 3 Theme</source>
+        <translation>Tema GTK 3</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="93"/>
+        <source>GTK 2 Theme</source>
+        <translation>Tema GTK 2</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="103"/>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation>Per provare ad uniformare il tema, seleziona uno stile/tema simile (se disponibile) nella lista, o seleziona &apos;gtk2&apos; Qt style (se disponibile) per mimare i temi GTK. 
+
+Assicurati che &apos;xsettingsd&apos; sia installato per aiutare le applicazioni GTK ad applicare i temi automaticamente.</translation>
+    </message>
+</context>
 <context>
     <name>IconThemeConfig</name>
     <message>
@@ -188,38 +230,62 @@
         <translation>Sostituisci sfondo desktop personalizzato</translation>
     </message>
 </context>
+<context>
+    <name>PalettesDialog</name>
+    <message>
+        <location filename="../palettes.ui" line="14"/>
+        <location filename="../palettes.ui" line="20"/>
+        <source>Palettes</source>
+        <translation>Schemi di colori</translation>
+    </message>
+    <message>
+        <location filename="../palettes.ui" line="33"/>
+        <source>Filter...</source>
+        <translation>Filtra...</translation>
+    </message>
+    <message>
+        <location filename="../palettes.ui" line="43"/>
+        <source>&amp;Remove</source>
+        <translation>&amp;Rimuovi</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../main.cpp" line="62"/>
         <source>LXQt Appearance Configuration</source>
         <translation>Configurazione dell&apos;aspetto di LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="71"/>
+        <location filename="../main.cpp" line="75"/>
         <source>Widget Style</source>
         <translation>Stile degli elementi</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="79"/>
+        <location filename="../main.cpp" line="84"/>
         <source>Icons Theme</source>
         <translation>Tema delle icone</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="88"/>
+        <location filename="../main.cpp" line="93"/>
         <source>LXQt Theme</source>
         <translation>Tema di LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../main.cpp" line="101"/>
         <source>Font</source>
         <translation>Carattere</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="106"/>
+        <location filename="../main.cpp" line="111"/>
         <source>Cursor</source>
         <translation>Puntatore</translation>
     </message>
+    <message>
+        <location filename="../main.cpp" line="118"/>
+        <source>GTK Style</source>
+        <translation>Stile GTK</translation>
+    </message>
 </context>
 <context>
     <name>StyleConfig</name>
@@ -246,7 +312,7 @@
     <message>
         <location filename="../styleconfig.ui" line="112"/>
         <source>View:</source>
-        <translation type="unfinished">Riquadro:</translation>
+        <translation>Riquadro:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="122"/>
@@ -279,66 +345,52 @@
         <translation>Collegamento visitato:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="227"/>
+        <location filename="../styleconfig.ui" line="214"/>
+        <source>&amp;Save Palette</source>
+        <translation>&amp;Salva schema</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="221"/>
+        <source>&amp;Load Palette</source>
+        <translation>&amp;Carica schema</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="241"/>
         <source>&amp;Default Palette</source>
         <translation>&amp;Ripristina</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="254"/>
-        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
-        <translation>Imposta tema GTK (verranno sovrascritti i file di configurazione di GTK!)</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="274"/>
-        <source>GTK 3 Theme</source>
-        <translation>Tema GTK 3</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="284"/>
-        <source>GTK 2 Theme</source>
-        <translation>Tema GTK 2</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="294"/>
-        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
-
-Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation>Per provare ad uniformare il tema, seleziona uno stile/tema simile (se disponibile) nella lista, o seleziona &apos;gtk2&apos; Qt style (se disponibile) per mimare i temi GTK. 
-
-Assicurati che &apos;xsettingsd&apos; sia installato per aiutare le applicazioni GTK ad applicare i temi automaticamente.</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="311"/>
+        <location filename="../styleconfig.ui" line="256"/>
         <source>Toolbar button style:</source>
         <translation>Stile della barra delle applicazioni:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="319"/>
+        <location filename="../styleconfig.ui" line="264"/>
         <source>Only display the icon</source>
         <translation>Mostra solo l&apos;icona</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="324"/>
+        <location filename="../styleconfig.ui" line="269"/>
         <source>Only display the text</source>
         <translation>Mostra solo il testo</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="329"/>
+        <location filename="../styleconfig.ui" line="274"/>
         <source>The text appears beside the icon</source>
         <translation>Testo accanto all&apos;icona</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="334"/>
+        <location filename="../styleconfig.ui" line="279"/>
         <source>The text appears under the icon</source>
         <translation>Testo sotto l&apos;icona</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="339"/>
+        <location filename="../styleconfig.ui" line="284"/>
         <source>Default</source>
         <translation>Predefinito</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="347"/>
+        <location filename="../styleconfig.ui" line="292"/>
         <source>Activate item on single click</source>
         <translation>Attiva elementi con un clic singolo</translation>
     </message>
@@ -347,5 +399,35 @@ Assicurati che &apos;xsettingsd&apos; sia installato per aiutare le applicazioni
         <source>Qt Style</source>
         <translation>Stile Qt</translation>
     </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <location filename="../styleconfig.cpp" line="255"/>
+        <source>Save Palette</source>
+        <translation>Salva schema</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <source>Palette name:</source>
+        <translation>Nome dello schema:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="256"/>
+        <source>A palette with the same name exists.
+Do you want to replace it?</source>
+        <translation>Un schema dello stesso nome esiste già.
+Sostituirlo?</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="393"/>
+        <source>Remove Palettes</source>
+        <translation>Rimuovi schemi</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="394"/>
+        <source>Do you really want to remove selected palette(s)?
+Root palettes will remain intact if existing.</source>
+        <translation>Si è sicuro di voler rimuovere lo schema selezionato?
+Eventuali schemi di root saranno conservati.</translation>
+    </message>
 </context>
 </TS>
