@@ -6,26 +6,36 @@
     <message>
         <location filename="../colorLabel.cpp" line="37"/>
         <source>Click to change color.</source>
-        <translation type="unfinished"></translation>
+        <translation>색상을 변경하려면 클릭하십시오.</translation>
     </message>
     <message>
         <location filename="../colorLabel.cpp" line="61"/>
         <source>Select Color</source>
-        <translation type="unfinished"></translation>
+        <translation>색상 선택</translation>
     </message>
 </context>
 <context>
     <name>ConfigOtherToolKits</name>
     <message>
-        <location filename="../configothertoolkits.cpp" line="148"/>
+        <location filename="../configothertoolkits.cpp" line="170"/>
         <source>GTK themes</source>
         <translation>GTK 테마</translation>
     </message>
     <message>
-        <location filename="../configothertoolkits.cpp" line="149"/>
+        <location filename="../configothertoolkits.cpp" line="171"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
         <translation>&lt;p&gt;&apos;%1&apos; 덮어 써졌습니다.&lt;/p&gt;&lt;p&gt;&apos;%2&apos;에서 이전 설정의 복사본을 찾으실 수 있습니다&lt;/p&gt;</translation>
     </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error</source>
+        <translation>오류</translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error: gsettings cannot be run</source>
+        <translation>오류: gsettings를 실행할 수 없습니다</translation>
+    </message>
 </context>
 <context>
     <name>FontsConfig</name>
@@ -77,7 +87,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="94"/>
         <source>The following settings only affect newly started applications</source>
-        <translation>다음의 설정은 새로 시작하는 애플리케이션에만 적용됩니다</translation>
+        <translation>다음 설정은 새로 시작된 응용 프로그램에만 영향을 줍니다</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="100"/>
@@ -151,12 +161,44 @@
         <translation>VBGR</translation>
     </message>
 </context>
+<context>
+    <name>GTKConfig</name>
+    <message>
+        <location filename="../gtkconfig.ui" line="44"/>
+        <source>GTK Style</source>
+        <translation>GTK 스타일</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="63"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
+        <translation>GTK 테마 지정 (GTK 구성 파일을 덮어씁니다!)</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="83"/>
+        <source>GTK 3 Theme</source>
+        <translation>GTK 3 테마</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="93"/>
+        <source>GTK 2 Theme</source>
+        <translation>GTK 2 테마</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="103"/>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation>균일한 테마를 시도하려면 모든 목록에서 유사한 스타일/테마(사용 가능한 경우)를 선택하거나 &apos;gtk2&apos; Qt 스타일(사용 가능한 경우)을 선택하여 GTK 테마를 모방합니다.
+
+GTK 응용 프로그램이 테마를 즉석에서 적용할 수 있도록 &apos;xsettingsd&apos;가 설치되어 있는지 확인하십시오.</translation>
+    </message>
+</context>
 <context>
     <name>IconThemeConfig</name>
     <message>
         <location filename="../iconthemeconfig.ui" line="14"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>LXQt 꾸미기설정</translation>
+        <translation>LXQt 모양새 구성</translation>
     </message>
     <message>
         <location filename="../iconthemeconfig.ui" line="26"/>
@@ -188,37 +230,61 @@
     </message>
 </context>
 <context>
-    <name>QObject</name>
+    <name>PalettesDialog</name>
     <message>
-        <location filename="../main.cpp" line="58"/>
-        <source>LXQt Appearance Configuration</source>
-        <translation>LXQt 꾸미기 설정</translation>
+        <location filename="../palettes.ui" line="14"/>
+        <location filename="../palettes.ui" line="20"/>
+        <source>Palettes</source>
+        <translation>팔레트</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="71"/>
+        <location filename="../palettes.ui" line="33"/>
+        <source>Filter...</source>
+        <translation>필터...</translation>
+    </message>
+    <message>
+        <location filename="../palettes.ui" line="43"/>
+        <source>&amp;Remove</source>
+        <translation>제거(&amp;R)</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="62"/>
+        <source>LXQt Appearance Configuration</source>
+        <translation>LXQt 모양새 구성</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="75"/>
         <source>Widget Style</source>
         <translation>위젯 스타일</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="79"/>
+        <location filename="../main.cpp" line="84"/>
         <source>Icons Theme</source>
         <translation>아이콘 테마</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="88"/>
+        <location filename="../main.cpp" line="93"/>
         <source>LXQt Theme</source>
         <translation>LXQt 테마</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../main.cpp" line="101"/>
         <source>Font</source>
         <translation>글꼴</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="106"/>
+        <location filename="../main.cpp" line="111"/>
         <source>Cursor</source>
         <translation>커서</translation>
     </message>
+    <message>
+        <location filename="../main.cpp" line="118"/>
+        <source>GTK Style</source>
+        <translation>GTK 스타일</translation>
+    </message>
 </context>
 <context>
     <name>StyleConfig</name>
@@ -230,114 +296,100 @@
     <message>
         <location filename="../styleconfig.ui" line="63"/>
         <source>Qt Palette</source>
-        <translation type="unfinished"></translation>
+        <translation>Qt 팔레트</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="77"/>
         <source>Some Qt styles may ignore these colors.</source>
-        <translation type="unfinished"></translation>
+        <translation>일부 Qt 스타일은 이러한 색상을 무시할 수 있습니다.</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="102"/>
         <source>Window:</source>
-        <translation type="unfinished"></translation>
+        <translation>창:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="112"/>
         <source>View:</source>
-        <translation type="unfinished"></translation>
+        <translation>보기:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="122"/>
         <source>Selection:</source>
-        <translation type="unfinished"></translation>
+        <translation>선택:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="132"/>
         <source>Link:</source>
-        <translation type="unfinished"></translation>
+        <translation>링크:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="152"/>
         <source>Window Text:</source>
-        <translation type="unfinished"></translation>
+        <translation>창 텍스트:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="162"/>
         <source>View Text:</source>
-        <translation type="unfinished"></translation>
+        <translation>보기 텍스트:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="172"/>
         <source>Selected Text:</source>
-        <translation type="unfinished"></translation>
+        <translation>선택한 텍스트:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="182"/>
         <source>Visited Link:</source>
-        <translation type="unfinished"></translation>
+        <translation>방문한 링크:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="227"/>
+        <location filename="../styleconfig.ui" line="214"/>
+        <source>&amp;Save Palette</source>
+        <translation>팔레트 저장(&amp;S)</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="221"/>
+        <source>&amp;Load Palette</source>
+        <translation>팔레트 불러오기(&amp;L)</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="241"/>
         <source>&amp;Default Palette</source>
-        <translation type="unfinished"></translation>
+        <translation>기본 팔레트(&amp;D)</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="254"/>
-        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
-        <translation>GTK 테마 설정 (GTK 설정 파일을 덮어씁니다!)</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="274"/>
-        <source>GTK 3 Theme</source>
-        <translation>GTK 3 테마</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="284"/>
-        <source>GTK 2 Theme</source>
-        <translation>GTK 2 테마</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="294"/>
-        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
-
-Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation>유니폼 테마를 시도하려면 모든 목록에서 유사한 스타일 / 테마 (가능한 경우)를 선택하거나 &apos;gtk2&apos;Qt 스타일 (가능한 경우)을 선택하여 GTK 테마를 따르세요.
-
-GTK 애플리케이션이 테마를 즉시 적용할 수 있도록 &apos;xsettingsd&apos;가 설치되어 있는지 확인해주세요.</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="311"/>
+        <location filename="../styleconfig.ui" line="256"/>
         <source>Toolbar button style:</source>
         <translation>툴바 버튼 스타일:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="319"/>
+        <location filename="../styleconfig.ui" line="264"/>
         <source>Only display the icon</source>
         <translation>아이콘만 보이기</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="324"/>
+        <location filename="../styleconfig.ui" line="269"/>
         <source>Only display the text</source>
-        <translation>글자만 보이기</translation>
+        <translation>텍스트만 보이기</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="329"/>
+        <location filename="../styleconfig.ui" line="274"/>
         <source>The text appears beside the icon</source>
-        <translation>아이콘 옆에 글자 보이기</translation>
+        <translation>아이콘 옆에 텍스트가 나타납니다</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="334"/>
+        <location filename="../styleconfig.ui" line="279"/>
         <source>The text appears under the icon</source>
-        <translation>아이콘 아래에 글자 보이기</translation>
+        <translation>아이콘 아래에 텍스트가 나타납니다</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="339"/>
+        <location filename="../styleconfig.ui" line="284"/>
         <source>Default</source>
         <translation>기본</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="347"/>
+        <location filename="../styleconfig.ui" line="292"/>
         <source>Activate item on single click</source>
         <translation>한 번 클릭으로 실행하기</translation>
     </message>
@@ -346,5 +398,35 @@ GTK 애플리케이션이 테마를 즉시 적용할 수 있도록 &apos;xsettin
         <source>Qt Style</source>
         <translation>Qt 스타일</translation>
     </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <location filename="../styleconfig.cpp" line="255"/>
+        <source>Save Palette</source>
+        <translation>팔레트 저장</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <source>Palette name:</source>
+        <translation>팔레트 이름:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="256"/>
+        <source>A palette with the same name exists.
+Do you want to replace it?</source>
+        <translation>같은 이름의 팔레트가 있습니다.
+교체하시겠습니까?</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="393"/>
+        <source>Remove Palettes</source>
+        <translation>팔레트 제거</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="394"/>
+        <source>Do you really want to remove selected palette(s)?
+Root palettes will remain intact if existing.</source>
+        <translation>선택한 팔레트를 정말로 제거하시겠습니까?
+루트 팔레트는 존재하는 경우 그대로 유지됩니다.</translation>
+    </message>
 </context>
 </TS>
