@@ -17,15 +17,25 @@
 <context>
     <name>ConfigOtherToolKits</name>
     <message>
-        <location filename="../configothertoolkits.cpp" line="148"/>
+        <location filename="../configothertoolkits.cpp" line="170"/>
         <source>GTK themes</source>
         <translation>Temas GTK</translation>
     </message>
     <message>
-        <location filename="../configothertoolkits.cpp" line="149"/>
+        <location filename="../configothertoolkits.cpp" line="171"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
         <translation>&lt;p&gt;&apos;%1&apos; foi sobrescrito.&lt;/p&gt;&lt;p&gt;Você pode encontrar uma cópia de suas configurações anteriores em &apos;%2&apos;&lt;/p&gt;</translation>
     </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error</source>
+        <translation>Erro</translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error: gsettings cannot be run</source>
+        <translation>Erro: gsettings não pode ser executado</translation>
+    </message>
 </context>
 <context>
     <name>FontsConfig</name>
@@ -151,6 +161,38 @@
         <translation>VBGR</translation>
     </message>
 </context>
+<context>
+    <name>GTKConfig</name>
+    <message>
+        <location filename="../gtkconfig.ui" line="44"/>
+        <source>GTK Style</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="63"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
+        <translation>Definir temas GTK (os arquivos de configuração do GTK serão sobrescritos)</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="83"/>
+        <source>GTK 3 Theme</source>
+        <translation>Tema GTK 3</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="93"/>
+        <source>GTK 2 Theme</source>
+        <translation>Tema GTK 2</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="103"/>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation>Para uma maior consistência visual do ambiente, selecione um tema/estilo similar (caso disponível) em todas as listas, ou selecione o estilo &apos;gtk2&apos; do Qt (se acessível) para imitar os temas GTK.
+
+Verifique se o pacote &apos;xsettingsd&apos; está instalado, para permitir com que os programas GTK mudem para os temas selecionados no ato da aplicação.</translation>
+    </message>
+</context>
 <context>
     <name>IconThemeConfig</name>
     <message>
@@ -187,38 +229,62 @@
         <translation>Substituir o papel de parede definido pelo usuário</translation>
     </message>
 </context>
+<context>
+    <name>PalettesDialog</name>
+    <message>
+        <location filename="../palettes.ui" line="14"/>
+        <location filename="../palettes.ui" line="20"/>
+        <source>Palettes</source>
+        <translation>Paletas</translation>
+    </message>
+    <message>
+        <location filename="../palettes.ui" line="33"/>
+        <source>Filter...</source>
+        <translation>Filtro...</translation>
+    </message>
+    <message>
+        <location filename="../palettes.ui" line="43"/>
+        <source>&amp;Remove</source>
+        <translation>&amp;Remover</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../main.cpp" line="62"/>
         <source>LXQt Appearance Configuration</source>
         <translation>Configuração da Aparência do LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="71"/>
+        <location filename="../main.cpp" line="75"/>
         <source>Widget Style</source>
         <translation>Estilo do Widget</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="79"/>
+        <location filename="../main.cpp" line="84"/>
         <source>Icons Theme</source>
         <translation>Tema de ícones</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="88"/>
+        <location filename="../main.cpp" line="93"/>
         <source>LXQt Theme</source>
         <translation>Tema do LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../main.cpp" line="101"/>
         <source>Font</source>
         <translation>Fonte</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="106"/>
+        <location filename="../main.cpp" line="111"/>
         <source>Cursor</source>
         <translation>Cursor</translation>
     </message>
+    <message>
+        <location filename="../main.cpp" line="118"/>
+        <source>GTK Style</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StyleConfig</name>
@@ -278,66 +344,52 @@
         <translation>Link Visitado:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="227"/>
+        <location filename="../styleconfig.ui" line="214"/>
+        <source>&amp;Save Palette</source>
+        <translation>&amp;Salvar paleta</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="221"/>
+        <source>&amp;Load Palette</source>
+        <translation>Carregar pa&amp;leta</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="241"/>
         <source>&amp;Default Palette</source>
         <translation>&amp;Paleta Padrão</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="254"/>
-        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
-        <translation>Definir temas GTK (os arquivos de configuração do GTK serão sobrescritos)</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="274"/>
-        <source>GTK 3 Theme</source>
-        <translation>Tema GTK 3</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="284"/>
-        <source>GTK 2 Theme</source>
-        <translation>Tema GTK 2</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="294"/>
-        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
-
-Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation>Para uma maior consistência visual do ambiente, selecione um tema/estilo similar (caso disponível) em todas as listas, ou selecione o estilo &apos;gtk2&apos; do Qt (se acessível) para imitar os temas GTK.
-
-Verifique se o pacote &apos;xsettingsd&apos; está instalado, para permitir com que os programas GTK mudem para os temas selecionados no ato da aplicação.</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="311"/>
+        <location filename="../styleconfig.ui" line="256"/>
         <source>Toolbar button style:</source>
         <translation>Estilo dos botões da barra de ferramentas:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="319"/>
+        <location filename="../styleconfig.ui" line="264"/>
         <source>Only display the icon</source>
         <translation>Mostrar apenas ícones</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="324"/>
+        <location filename="../styleconfig.ui" line="269"/>
         <source>Only display the text</source>
         <translation>Mostrar apenas texto</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="329"/>
+        <location filename="../styleconfig.ui" line="274"/>
         <source>The text appears beside the icon</source>
         <translation>O texto aparece ao lado do ícone</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="334"/>
+        <location filename="../styleconfig.ui" line="279"/>
         <source>The text appears under the icon</source>
         <translation>O texto aparece abaixo do ícone</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="339"/>
+        <location filename="../styleconfig.ui" line="284"/>
         <source>Default</source>
         <translation>Padrão</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="347"/>
+        <location filename="../styleconfig.ui" line="292"/>
         <source>Activate item on single click</source>
         <translation>Ativar item com clique único</translation>
     </message>
@@ -346,5 +398,35 @@ Verifique se o pacote &apos;xsettingsd&apos; está instalado, para permitir com
         <source>Qt Style</source>
         <translation>Estilo Qt</translation>
     </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <location filename="../styleconfig.cpp" line="255"/>
+        <source>Save Palette</source>
+        <translation>Salvar paleta</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <source>Palette name:</source>
+        <translation>Nome da paleta:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="256"/>
+        <source>A palette with the same name exists.
+Do you want to replace it?</source>
+        <translation>Existe uma paleta com o mesmo nome.
+Deseja substituí-la?</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="393"/>
+        <source>Remove Palettes</source>
+        <translation>Remover paletas</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="394"/>
+        <source>Do you really want to remove selected palette(s)?
+Root palettes will remain intact if existing.</source>
+        <translation>Tem certeza de que deseja remover as paletas selecionadas?
+As paletas raiz permanecerão intactas, se existentes.</translation>
+    </message>
 </context>
 </TS>
