@@ -17,15 +17,25 @@
 <context>
     <name>ConfigOtherToolKits</name>
     <message>
-        <location filename="../configothertoolkits.cpp" line="148"/>
+        <location filename="../configothertoolkits.cpp" line="170"/>
         <source>GTK themes</source>
         <translation>GTK主題</translation>
     </message>
     <message>
-        <location filename="../configothertoolkits.cpp" line="149"/>
+        <location filename="../configothertoolkits.cpp" line="171"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
         <translation>&lt;p&gt;&apos;%1&apos; 已經被覆寫。&lt;/p&gt;&lt;p&gt;你可在&apos;%2&apos;中找到你舊設定的備份&lt;/p&gt;</translation>
     </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="235"/>
+        <source>Error: gsettings cannot be run</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FontsConfig</name>
@@ -151,6 +161,38 @@
         <translation>VBGR (灰藍綠紅)</translation>
     </message>
 </context>
+<context>
+    <name>GTKConfig</name>
+    <message>
+        <location filename="../gtkconfig.ui" line="44"/>
+        <source>GTK Style</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="63"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
+        <translation>設定GTK主題 (GTK設定將會被覆蓋!)</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="83"/>
+        <source>GTK 3 Theme</source>
+        <translation>GTK 3主題</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="93"/>
+        <source>GTK 2 Theme</source>
+        <translation>GTK 2主題</translation>
+    </message>
+    <message>
+        <location filename="../gtkconfig.ui" line="103"/>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation>要嘗試統一主題，請在所有列表中選擇相似的樣式/主題（如果可用），或選擇“gtk2”Qt樣式（如果可用）來模仿GTK主題。
+
+確保安裝&apos;xsettingsd&apos;以幫助GTK應用程序動態應用主題。</translation>
+    </message>
+</context>
 <context>
     <name>IconThemeConfig</name>
     <message>
@@ -187,38 +229,62 @@
         <translation>覆蓋使用者自訂的桌面背景</translation>
     </message>
 </context>
+<context>
+    <name>PalettesDialog</name>
+    <message>
+        <location filename="../palettes.ui" line="14"/>
+        <location filename="../palettes.ui" line="20"/>
+        <source>Palettes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../palettes.ui" line="33"/>
+        <source>Filter...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../palettes.ui" line="43"/>
+        <source>&amp;Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../main.cpp" line="62"/>
         <source>LXQt Appearance Configuration</source>
         <translation>LXQt自訂外觀</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="71"/>
+        <location filename="../main.cpp" line="75"/>
         <source>Widget Style</source>
         <translation>小工具樣式</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="79"/>
+        <location filename="../main.cpp" line="84"/>
         <source>Icons Theme</source>
         <translation>圖示主題</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="88"/>
+        <location filename="../main.cpp" line="93"/>
         <source>LXQt Theme</source>
         <translation>LXQt主題</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../main.cpp" line="101"/>
         <source>Font</source>
         <translation>字型</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="106"/>
+        <location filename="../main.cpp" line="111"/>
         <source>Cursor</source>
         <translation>游標</translation>
     </message>
+    <message>
+        <location filename="../main.cpp" line="118"/>
+        <source>GTK Style</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StyleConfig</name>
@@ -278,66 +344,52 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="227"/>
+        <location filename="../styleconfig.ui" line="214"/>
+        <source>&amp;Save Palette</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="221"/>
+        <source>&amp;Load Palette</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="241"/>
         <source>&amp;Default Palette</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="254"/>
-        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
-        <translation>設定GTK主題 (GTK設定將會被覆蓋!)</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="274"/>
-        <source>GTK 3 Theme</source>
-        <translation>GTK 3主題</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="284"/>
-        <source>GTK 2 Theme</source>
-        <translation>GTK 2主題</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="294"/>
-        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
-
-Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation>要嘗試統一主題，請在所有列表中選擇相似的樣式/主題（如果可用），或選擇“gtk2”Qt樣式（如果可用）來模仿GTK主題。
-
-確保安裝&apos;xsettingsd&apos;以幫助GTK應用程序動態應用主題。</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="311"/>
+        <location filename="../styleconfig.ui" line="256"/>
         <source>Toolbar button style:</source>
         <translation>工具列按鈕樣式：</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="319"/>
+        <location filename="../styleconfig.ui" line="264"/>
         <source>Only display the icon</source>
         <translation>僅顯示圖示</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="324"/>
+        <location filename="../styleconfig.ui" line="269"/>
         <source>Only display the text</source>
         <translation>僅顯示文字</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="329"/>
+        <location filename="../styleconfig.ui" line="274"/>
         <source>The text appears beside the icon</source>
         <translation>圖示旁顯示文字</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="334"/>
+        <location filename="../styleconfig.ui" line="279"/>
         <source>The text appears under the icon</source>
         <translation>圖示下顯示文字</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="339"/>
+        <location filename="../styleconfig.ui" line="284"/>
         <source>Default</source>
         <translation>預設</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="347"/>
+        <location filename="../styleconfig.ui" line="292"/>
         <source>Activate item on single click</source>
         <translation>單擊選擇物件</translation>
     </message>
@@ -346,5 +398,33 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
         <source>Qt Style</source>
         <translation>Qt風格</translation>
     </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <location filename="../styleconfig.cpp" line="255"/>
+        <source>Save Palette</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="245"/>
+        <source>Palette name:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="256"/>
+        <source>A palette with the same name exists.
+Do you want to replace it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="393"/>
+        <source>Remove Palettes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.cpp" line="394"/>
+        <source>Do you really want to remove selected palette(s)?
+Root palettes will remain intact if existing.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
