@@ -108,10 +108,10 @@ static bool xi2_set_device_property(int deviceid, const char* prop, QList<QVaria
 
     XFree(data);
 
-    auto dataType = values[0].type();
+    auto dataType = static_cast<QMetaType::Type>(values[0].type());
     switch (dataType)
     {
-    case QVariant::Int:
+    case QMetaType::Int:
         Q_ASSERT(act_type == XA_INTEGER);
 
         data = new unsigned char[values.size() * act_format / 8];
@@ -201,6 +201,7 @@ QList<TouchpadDevice> TouchpadDevice::enumerate_from_udev()
             if(dev.find_xi2_device())
             {
                 qDebug() << "Detected" << dev.m_name << "on" << dev.devnode;
+                qDebug() << "xinput driver:" << dev.xinputDriver();
                 dev.m_oldTappingEnabled = dev.tappingEnabled();
                 dev.m_oldNaturalScrollingEnabled = dev.naturalScrollingEnabled();
                 dev.m_oldTapToDragEnabled = dev.tapToDragEnabled();
@@ -234,6 +235,17 @@ bool TouchpadDevice::find_xi2_device()
         {
             m_name = QString::fromUtf8(info[i].name);
             deviceid = info[i].deviceid;
+
+            // init xinput driver name
+            auto xi_driver_prop = xi2_get_device_property(deviceid, "Synaptics Capabilities");
+            if (xi_driver_prop.size()) {
+              // lxqt does not support xf86-input-synaptics properties
+              m_xinputDriver = QStringLiteral("synaptics");
+            } else {
+              // otherweise we assumge libinput and don't test on libinput properties
+              m_xinputDriver = QStringLiteral("libinput");
+            }
+
             found = true;
             break;
         }
@@ -253,7 +265,7 @@ QString TouchpadDevice::escapedName() const
 
 void TouchpadDevice::loadSettings(LXQt::Settings* settings)
 {
-    QList<TouchpadDevice> devices = enumerate_from_udev();
+    const QList<TouchpadDevice> devices = enumerate_from_udev();
     settings->beginGroup(QStringLiteral("Touchpad"));
     for (const TouchpadDevice& device : devices) {
         qDebug() << "Load settings for" << device.name();
