@@ -4,92 +4,92 @@
 <context>
     <name>LocaleConfig</name>
     <message>
-        <location filename="../localeconfig.ui" line="47"/>
+        <location filename="../localeconfig.ui" line="31"/>
         <source>Re&amp;gion:</source>
         <translation>Re&amp;gionas:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="76"/>
+        <location filename="../localeconfig.ui" line="60"/>
         <source>De&amp;tailed Settings</source>
         <translation>Iš&amp;samūs nustatymai</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="83"/>
+        <location filename="../localeconfig.ui" line="78"/>
         <source>&amp;Numbers:</source>
         <translation>&amp;Skaičiai:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="112"/>
+        <location filename="../localeconfig.ui" line="107"/>
         <source>&amp;Time:</source>
         <translation>&amp;Laikas:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="141"/>
+        <location filename="../localeconfig.ui" line="136"/>
         <source>Currenc&amp;y:</source>
         <translation>Valiu&amp;ta:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="170"/>
+        <location filename="../localeconfig.ui" line="165"/>
         <source>Measurement &amp;Units:</source>
         <translation>&amp;Matavimo vienetai:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="199"/>
+        <location filename="../localeconfig.ui" line="194"/>
         <source>Co&amp;llation and Sorting:</source>
         <translation>L&amp;yginimas ir rikiavimas:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="238"/>
-        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Pavyzdžiai&lt;/b&gt;</translation>
+        <location filename="../localeconfig.ui" line="226"/>
+        <source>Examples</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="248"/>
+        <location filename="../localeconfig.ui" line="238"/>
         <source>Numbers:</source>
         <translation>Skaičiai:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="268"/>
+        <location filename="../localeconfig.ui" line="258"/>
         <source>Time:</source>
         <translation>Laikas:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="288"/>
+        <location filename="../localeconfig.ui" line="278"/>
         <source>Currency:</source>
         <translation>Valiuta:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="308"/>
+        <location filename="../localeconfig.ui" line="298"/>
         <source>Measurement Units:</source>
         <translation>Matavimo vienetai:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="127"/>
+        <location filename="../localeconfig.cpp" line="126"/>
         <source>No change</source>
         <translation>Be pakeitimų</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="316"/>
+        <location filename="../localeconfig.cpp" line="313"/>
         <source>Format Settings Changed</source>
         <translation>Formato nustatymai pakeisti</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="317"/>
+        <location filename="../localeconfig.cpp" line="314"/>
         <source>Do you want to save your changes? They will take effect the next time you log in.</source>
         <translation>Ar norite įrašyti savo pakeitimus? Jie įsigalios, kai kitą kartą prisijungsite.</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="438"/>
+        <location filename="../localeconfig.cpp" line="417"/>
         <source>Imperial UK</source>
         <translation>Imperinė (Jungtinė Karalystė)</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="442"/>
+        <location filename="../localeconfig.cpp" line="421"/>
         <source>Imperial US</source>
         <translation>Imperinė (JAV)</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="446"/>
+        <location filename="../localeconfig.cpp" line="425"/>
         <source>Metric</source>
         <translation>Metriniai</translation>
     </message>
