@@ -4,92 +4,92 @@
 <context>
     <name>LocaleConfig</name>
     <message>
-        <location filename="../localeconfig.ui" line="47"/>
+        <location filename="../localeconfig.ui" line="31"/>
         <source>Re&amp;gion:</source>
-        <translation>Re&amp;gion :</translation>
+        <translation>Re&amp;gion&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="76"/>
+        <location filename="../localeconfig.ui" line="60"/>
         <source>De&amp;tailed Settings</source>
         <translation>De&amp;tals dels reglatges</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="83"/>
+        <location filename="../localeconfig.ui" line="78"/>
         <source>&amp;Numbers:</source>
-        <translation>&amp;Nombres :</translation>
+        <translation>&amp;Nombres&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="112"/>
+        <location filename="../localeconfig.ui" line="107"/>
         <source>&amp;Time:</source>
-        <translation>&amp;Ora :</translation>
+        <translation>&amp;Ora&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="141"/>
+        <location filename="../localeconfig.ui" line="136"/>
         <source>Currenc&amp;y:</source>
-        <translation>&amp;Devisa :</translation>
+        <translation>&amp;Devisa&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="170"/>
+        <location filename="../localeconfig.ui" line="165"/>
         <source>Measurement &amp;Units:</source>
-        <translation>&amp;Unitats de mesura :</translation>
+        <translation>&amp;Unitats de mesura&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="199"/>
+        <location filename="../localeconfig.ui" line="194"/>
         <source>Co&amp;llation and Sorting:</source>
-        <translation>&amp;Tria e règlas de classament :</translation>
+        <translation>&amp;Tria e règlas de classament&#x202f;:</translation>
+    </message>
+    <message>
+        <location filename="../localeconfig.ui" line="226"/>
+        <source>Examples</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../localeconfig.ui" line="238"/>
-        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Exemples&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="../localeconfig.ui" line="248"/>
         <source>Numbers:</source>
-        <translation>Nombres :</translation>
+        <translation>Nombres&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="268"/>
+        <location filename="../localeconfig.ui" line="258"/>
         <source>Time:</source>
-        <translation>Ora :</translation>
+        <translation>Ora&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="288"/>
+        <location filename="../localeconfig.ui" line="278"/>
         <source>Currency:</source>
-        <translation>Devisa :</translation>
+        <translation>Devisa&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.ui" line="308"/>
+        <location filename="../localeconfig.ui" line="298"/>
         <source>Measurement Units:</source>
-        <translation>Unitats de mesura :</translation>
+        <translation>Unitats de mesura&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="127"/>
+        <location filename="../localeconfig.cpp" line="126"/>
         <source>No change</source>
         <translation>Cap de cambiament</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="316"/>
+        <location filename="../localeconfig.cpp" line="313"/>
         <source>Format Settings Changed</source>
         <translation>Paramètres del format modificats</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="317"/>
+        <location filename="../localeconfig.cpp" line="314"/>
         <source>Do you want to save your changes? They will take effect the next time you log in.</source>
-        <translation>Volètz enregistrar las modificacions ? S’aplicaràn a la connexion venenta.</translation>
+        <translation>Volètz enregistrar las modificacions&#x202f;? S’aplicaràn a la connexion venenta.</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="438"/>
+        <location filename="../localeconfig.cpp" line="417"/>
         <source>Imperial UK</source>
         <translation>Imperial Reialme-Unit</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="442"/>
+        <location filename="../localeconfig.cpp" line="421"/>
         <source>Imperial US</source>
         <translation>Imperial Estats-Units</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="446"/>
+        <location filename="../localeconfig.cpp" line="425"/>
         <source>Metric</source>
         <translation>Metric</translation>
     </message>
