@@ -34,7 +34,7 @@
     <message>
         <location filename="../loadsettings.cpp" line="97"/>
         <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
-        <translation>Byla použita výchozí nastavení obrazovky. Pokud chcete nastavení obrazovky změnit. Použijte, prosím, lxqt-config-monitor.</translation>
+        <translation>Byla použita výchozí nastavení obrazovky. Pokud chcete nastavení obrazovky změnit. Použijte lxqt-config-monitor.</translation>
     </message>
 </context>
 <context>
@@ -135,7 +135,7 @@
     <message>
         <location filename="../monitorsettingsdialog.cpp" line="109"/>
         <source>Set position</source>
-        <translation>Nastavit polohu</translation>
+        <translation>Nastavit pozici</translation>
     </message>
     <message>
         <location filename="../monitorsettingsdialog.cpp" line="228"/>
@@ -188,7 +188,7 @@
     <message>
         <location filename="../monitorwidget.ui" line="146"/>
         <source>Refresh rate:</source>
-        <translation>Frekvence obnovování obrazu:</translation>
+        <translation>Frekvence překreslování obrazu:</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="153"/>
