@@ -310,7 +310,7 @@
         <location filename="../timeoutdialog.cpp" line="63"/>
         <source>%n second(s) remaining</source>
         <translation>
-            <numerusform>נותרה שניה אחת</numerusform>
+            <numerusform>נותרה שנייה אחת</numerusform>
             <numerusform>נותרו %n שניות</numerusform>
             <numerusform>נותרו %n שניות</numerusform>
             <numerusform>נותרו %n שניות</numerusform>
