@@ -34,7 +34,7 @@
     <message>
         <location filename="../loadsettings.cpp" line="97"/>
         <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
-        <translation>既定のモニタ設定が適用しました。モニタ設定を変更したい場合は、lxqt-config-monitor を使用して下さい。</translation>
+        <translation>既定のモニター設定を適用しました。モニター設定を変更する場合は lxqt-config-monitor を使用して下さい。</translation>
     </message>
 </context>
 <context>
@@ -183,7 +183,7 @@
     <message>
         <location filename="../monitorwidget.ui" line="125"/>
         <source>Advanced</source>
-        <translation>高度</translation>
+        <translation>詳細</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="146"/>
@@ -299,12 +299,12 @@
     <message>
         <location filename="../timeoutdialog.ui" line="14"/>
         <source>Settings are changed</source>
-        <translation>設定は変更されました</translation>
+        <translation>設定が変更されました</translation>
     </message>
     <message>
         <location filename="../timeoutdialog.ui" line="46"/>
         <source>Are the current settings OK for you?</source>
-        <translation>この設定で問題ないですか？</translation>
+        <translation>この設定で大丈夫ですか？</translation>
     </message>
     <message numerus="yes">
         <location filename="../timeoutdialog.cpp" line="63"/>
